# Dashboard plugin

This plugin manages and displays all available widgets registered in the plugins.
It defines a widget interface Widget in order to facilitate the definition and integration of a new widget.
